<?php
namespace Amazon\Affiliate\Admin;
/**
 * Class ProductsSearchWithoutApi
 *
 * @package Amazon\Affiliate\Admin
 */
class ProductsSearchWithoutApi extends ImportProducts {
    /**
     * Load product search page view
     */
    public function products_page() {
        $this->get_amazon_cat();
        $this->get_wc_terms();
        $template = __DIR__ . '/views/proudcts-search-without-api.php';
        if ( file_exists( $template ) ) {
            require_once $template;
        }
    }
    /**
     * Amazon product category
     *
     * @return string[]
     */
    public function get_option( $name ) {
        $option =  get_option( $name );
        return  $option;
    }
    public function get_amazon_cat() {
        $all_country_cat = ams_amazon_departments();
        $country         = get_option( 'ams_amazon_country' );
        $cat = array( 'com.mx', 'com.br', 'it', 'in', 'es', 'cn' );
        if ( in_array( $country, $cat) ) {
            $category = $all_country_cat['com'];
        } else {
            $category = $all_country_cat[ $country ];
        }
        return $category;
    }
    function get_wc_terms() {
        $categories = get_terms( array(
            'hide_empty' => false,
        ) );
// echo "<pre>";print_r($categories);die;
        $cat = array();
        foreach ( $categories as $row ) {
            if ( 'product_cat' === $row->taxonomy ) {
                $cat[] = array(
                    'term_id'  => $row->term_id,
                    'name'  => $row->name,
                );
            }
        }
        return array_reverse( $cat );
    }
    /**
     * Amazon products search
     */
    public function get_product_list() {
        $nonce = sanitize_text_field( $_POST['nonce'] );
        if ( ! wp_verify_nonce( $nonce, 'ams_without_api' ) ) {
            echo esc_html__( 'Busted!', 'ams-wc-amazon' );
            wp_die();
        }
        $this->active_site();
        //sanitize_text_field
        $data = ams_clean( $_POST['data'] );
 // echo "<pre>";print_r($_POST);die;
        foreach ( $data as $row ) {
            $asin            = $row['ASIN'];
            $title           = $row['Title'];
            $amount          = $row['Price'];
            $img             = $row['ImageUrl'];
            $detail_page_url = $row['DetailPageURL'];
            ?>
                <div class="col-lg-2 col-md-4 col-sm-6 p-1">
                    <div class="card">
                        <div class="product-item card-body" style="min-height: 452px">
                            <!--Ribbon-->
                            <div class="ribbon-wrapper">
                                <div class="ribbon"> Trending </div>
                            </div>
                            <!--//Ribbon-->
                            <img src="<?php echo esc_attr($img); ?>" alt="<?php esc_attr($title);?>">
                            <a href="<?php echo esc_attr($detail_page_url); ?>" target="_blank" title="<?php esc_attr($title);?>" class="product-item__name">
                                <?php echo esc_html(substr($title,0,30).'...'); ?>
                            </a>
                            <div class="product-item__description">
                            <?php if(!empty($amount)) { ?>
                                <span><?php echo esc_html($amount); ?> <small class="wca-delete"> <?php echo esc_html($saving_amount); ?></small></span>
                            <?php } else { ?>
                                <span class="text-muted">Price Not Available</span>
                            <?php } ?>
                                <a href="<?php echo esc_attr($detail_page_url); ?>" target="_blank" class="d-block"> <small> View Product </small></a>
                            </div>
                            <div class="product-item__price">
                            <?php
                                $ams_all_asin = ams_get_all_products_info();
                                if (in_array($asin, $ams_all_asin['asin'])) {
                                ?>
                                <button disabled type="button" class="btn btn-block btn-primary mt-3 d-block text-center imported wca-add-to-imported" ><?php echo esc_html__( 'Already Imported', 'ams-wc-amazon' ); ?></button>
                                <?php
                                } else {
                                ?>
                                    <button id="import_btn" type="button" class="btn btn-block btn-primary mt-3 d-block text-center wca-import-without-api" data-title="<?php echo esc_attr( $title ); ?>" data-amount="<?php echo esc_attr( $amount ); ?>" data-img="<?php echo esc_attr( $img ); ?>" data-detail-page-url="<?php echo esc_attr( $detail_page_url ); ?>" data-asin="<?php echo esc_attr( $asin ); ?> " >
                                        <?php echo esc_html__('Import Product', 'ams-wc-amazon'); ?>
                                    </button>
                                <?php
                                }
                            ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php
        }
        wp_die();
    }
    /**
     * WooCommerce product import form Amazon
     */
    function get_string_between($string, $start, $end){
        $string = ' ' . $string;
        $ini = strpos($string, $start);
        if ($ini == 0) return '';
        $ini += strlen($start);
        $len = strpos($string, $end, $ini) - $ini;
        return substr($string, $ini, $len);
    }
    public function product_import_without_api() {
        
        $regions      = ams_get_amazon_regions();
        if(!isset($_POST['is_cron']) || $_POST['is_cron'] != 1){
            $region   = $regions[ $locale ]['RegionCode'];
        } else {
            $region   = isset($_POST['region']) ? $_POST['region'] : "";
        }
        $nonce = $_POST['nonce'];
        $ams_all_asin = ams_get_all_products_info();
        if ( ! wp_verify_nonce( $nonce, 'ams_without_api' ) ) {
            die ( esc_html__( 'Busted!', 'ams-wc-amazon' ) );
        }
        if ( ams_plugin_license_status()  === false ) {
            $license = sprintf( "<h4 class='wca-warning'>%s</h4>", esc_html__( 'Please activate the plugin license before searching the product.', 'ams-wc-amazon' ) );
            echo wp_kses_post( $license );
            wp_die();
        }
        $asin  = sanitize_text_field( $_POST['asin'] );
        if (!empty($ams_all_asin['asin'])) {
            if ( in_array( $asin,  $ams_all_asin['asin'] ) ) {
                $massage = '<span class="dashicons dashicons-saved"></span> ' . esc_html__( 'Success', 'ams-wc-amazon' );
                echo wp_kses_post( $massage );
            }
        }
        $title = sanitize_text_field( $_POST['title'] );
        $image = esc_url( $_POST['img'] );
        $detail_page_url = esc_url( $_POST['detail_page_url'] );
        $gallery = array();
        $product_status = 'instock';


        //$response_body = $this->getAmazonPageHtml($detail_page_url);
        $product_url = sanitize_text_field( $detail_page_url );
        $user_agent = $this->user_agent();
        $options = array(
            'http' => array(
                'method' => "GET",
                'header' => "Accept-language: en\r\n" .
                    $user_agent
            )
        );
        // code run wait
        sleep( rand( 1, 5 ) );
        $context = stream_context_create( $options );
        // wp_remote_get() not working properly so I'm forced to use it
        $response_body = $page = file_get_contents( esc_url_raw( $product_url ), false, $context );




        if(!empty($response_body)) {
            if ( ! class_exists( 'simple_html_dom' ) ) {
                require_once AMS_PLUGIN_PATH . '/includes/Admin/lib/simplehtmldom/simple_html_dom.php';
            }
            $html = new \simple_html_dom();
            $html->load( $response_body );
            if ( $html->find( '#outOfStock .a-color-price', 0 ) ) {
                $product_status = 'outofstock';
            }
            $content = $this->fetchContentFromHtml($html);
            if(!empty($content)) {
                $pricing = $this->fetchPriceFromHtml($html);
                $amount = $pricing['amount'];
                $regular_price = $pricing['regular_price'];
                $gallery = $this->fetchImagesFromHtml($html);
                $image = $gallery[0];
                unset($gallery[0]);
                $user_id = get_current_user();
                $post_id = wp_insert_post( array(
                    'post_author'  => $user_id,
                    'post_title'   => stripslashes($title),
                    'post_content' => $content,
                    'post_status'  => 'publish',
                    'post_type'    => "product",
                    'post_parent'  => '',
                ));
                wp_set_object_terms( $post_id, 'simple', 'product_type' );
                $product_category = $this->syncAndGetCategory($html);
                if(!empty($product_category)) {
                    wp_set_object_terms($post_id, $product_category, 'product_cat');
                }
                update_post_meta( $post_id, '_visibility', 'visible' );
                update_post_meta( $post_id, '_stock_status', $product_status );
                update_post_meta( $post_id, 'total_sales', '0' );
                update_post_meta( $post_id, '_downloadable', 'no' );
                update_post_meta( $post_id, '_virtual', 'yes' );
                update_post_meta( $post_id, '_sale_price', $amount );
                update_post_meta( $post_id, '_purchase_note', '' );
                update_post_meta( $post_id, '_featured', 'no' );
                update_post_meta( $post_id, '_weight', '' );
                update_post_meta( $post_id, '_length', '' );
                update_post_meta( $post_id, '_width', '' );
                update_post_meta( $post_id, '_height', '' );
                update_post_meta( $post_id, '_sku', $asin );
                update_post_meta( $post_id, '_product_attributes', array() );
                update_post_meta( $post_id, '_sale_price_dates_from', '' );
                update_post_meta( $post_id, '_sale_price_dates_to', '' );
                update_post_meta( $post_id, '_price', $amount );
                update_post_meta($post_id, '_regular_price', $regular_price);
                update_post_meta( $post_id, '_sold_individually', '' );
                update_post_meta( $post_id, '_manage_stock', 'no' );
                update_post_meta( $post_id, '_backorders', 'no' );
                update_post_meta( $post_id, '_stock', '' );
                update_post_meta( $post_id, '_wca_amazon_affiliate_asin', $asin );
                update_post_meta( $post_id, '_region', $region );
                update_post_meta( $post_id, '_import_method', '2' );
                update_post_meta( $post_id, '_detail_page_url', $detail_page_url);
                if ( 'Yes' === get_option( 'ams_remote_amazon_images' ) ) {
                    $this->attach_product_thumbnail( $post_id, $image, 0 );
                    foreach( $gallery as $image ) {
                        $this->attach_product_thumbnail( $post_id, $image, 1 );
                    }
                }
                $massage = '<span class="dashicons dashicons-saved"></span> ' . esc_html__( 'Success', 'ams-wc-amazon' );
            } else {
                $massage = '<span class="dashicons dashicons-info-outline"></span> ' . esc_html__( 'Product not imported because product content is empty!', 'ams-wc-amazon' );
            }            
        } else {
            $massage = '<span class="dashicons dashicons-info-outline"></span>'.esc_html__( 'Something went wrong!', 'ams-wc-amazon' );
        }
        echo wp_kses_post( $massage );
        wp_die();
    }
    function file_get_contents_utf8($fn) {
        $content = file_get_contents($fn);
         return mb_convert_encoding($content, 'UTF-8',
             mb_detect_encoding($content, 'UTF-8, ISO-8859-1', true));
   }
    /**
     * Checking domain name
     */
    public function active_site() {
        $ams_activated_site = get_option( 'ams_activated_site' );
        $url                = $_SERVER['HTTP_HOST'];
        if ( strtolower( $ams_activated_site ) != strtolower( $url ) ) {
            $license = sprintf( "<h4 class='wca-warning'>%s</h4>", esc_html__( 'You have cloned the website Please activate the license on the website.', 'ams-wc-amazon' ) );
            echo wp_kses_post( $license );
            wp_die();
        }
    }
    /**
     * Get product thumbnail url
     */
    public function get_product_thumbnail_url( $element ) {
        return preg_replace(  '/(._.*_.)/i','.', $element->src );
    }
}